@@ -2,7 +2,7 @@
   This file is part of libkldap.
 
   Copyright (c) 2002-2009 Tobias Koenig <tokoe@kde.org>
-  Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
+  Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General  Public
@@ -46,8 +46,8 @@
 
 #include "addhostdialog.h"
 
-K_PLUGIN_FACTORY_WITH_JSON(KCMLdapFactory, "kcmldap.json", registerPlugin<KCMLdap>();
-                           )
+K_PLUGIN_CLASS_WITH_JSON(KCMLdap, "kcmldap.json")
+
 
 class LDAPItem : public QListWidgetItem
 {
@@ -85,7 +85,7 @@ public:
 
 private:
     KLDAP::LdapServer mServer;
-    bool mIsActive;
+    bool mIsActive = false;
 };
 
 KCMLdap::KCMLdap(QWidget *parent, const QVariantList &)
@@ -144,7 +144,7 @@ void KCMLdap::slotAddHost()
     KLDAP::LdapServer server;
     KLDAP::AddHostDialog dlg(&server, dialogParent());
 
-    if (dlg.exec() && !server.host().isEmpty()) {   //krazy:exclude=crashy
+    if (dlg.exec() && !server.host().trimmed().isEmpty()) {   //krazy:exclude=crashy
         new LDAPItem(mHostListView, server);
 
         Q_EMIT changed(true);
@@ -275,6 +275,7 @@ void KCMLdap::load()
 
 void KCMLdap::save()
 {
+    mClientSearchConfig->clearWalletPassword();
     KConfig *config = KLDAP::LdapClientSearchConfig::config();
     config->deleteGroup("LDAP");
 
@@ -305,11 +306,6 @@ void KCMLdap::save()
     Q_EMIT changed(false);
 }
 
-void KCMLdap::defaults()
-{
-    // add default configuration here
-}
-
 void KCMLdap::initGUI()
 {
     QVBoxLayout *layout = new QVBoxLayout(this);
