@@ -5,7 +5,7 @@
  *
  *      Ported to KABC by Daniel Molkentin <molkentin@kde.org>
  *
- * Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
+ * Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -74,17 +74,17 @@ public:
     void slotDataTimer();
     void slotFileChanged(const QString &);
 
-    LdapClientSearch *q;
+    LdapClientSearch *q = nullptr;
     QList<LdapClient *> mClients;
     QStringList mAttributes;
     QString mSearchText;
     QString mFilter;
     QTimer mDataTimer;
-    int mActiveClients;
-    bool mNoLDAPLookup;
+    int mActiveClients = 0;
+    bool mNoLDAPLookup = false;
     LdapResultObject::List mResults;
     QString mConfigFile;
-    LdapClientSearchConfig *mClientSearchConfig;
+    LdapClientSearchConfig *mClientSearchConfig = nullptr;
 };
 
 LdapClientSearch::LdapClientSearch(QObject *parent)
@@ -110,8 +110,9 @@ LdapClientSearch::LdapClientSearch(QObject *parent)
                                 "(|(cn=%1*)(mail=%1*)(givenName=%1*)(sn=%1*))");
 
     d->readConfig();
-    connect(KDirWatch::self(), SIGNAL(dirty(QString)), this,
-            SLOT(slotFileChanged(QString)));
+    connect(KDirWatch::self(), &KDirWatch::dirty, this, [this](const QString &filename) {
+        d->slotFileChanged(filename);
+    });
 }
 
 LdapClientSearch::~LdapClientSearch()
@@ -188,17 +189,23 @@ void LdapClientSearch::Private::readConfig()
 
             ldapClient->setAttributes(mAttributes);
 
-            q->connect(ldapClient, SIGNAL(result(KLDAP::LdapClient,KLDAP::LdapObject)),
-                       q, SLOT(slotLDAPResult(KLDAP::LdapClient,KLDAP::LdapObject)));
-            q->connect(ldapClient, SIGNAL(done()),
-                       q, SLOT(slotLDAPDone()));
-            q->connect(ldapClient, SIGNAL(error(QString)),
-                       q, SLOT(slotLDAPError(QString)));
+            q->connect(ldapClient, &LdapClient::result,
+                       q, [this](const LdapClient &client, const KLDAP::LdapObject &obj) { slotLDAPResult(client, obj); });
+            q->connect(ldapClient, &LdapClient::done,
+                       q, [this]() {
+                slotLDAPDone();
+            });
+            q->connect(ldapClient, QOverload<const QString &>::of(&LdapClient::error),
+                       q, [this](const QString &str) {
+                slotLDAPError(str);
+            });
 
             mClients.append(ldapClient);
         }
 
-        q->connect(&mDataTimer, SIGNAL(timeout()), SLOT(slotDataTimer()));
+        q->connect(&mDataTimer, &QTimer::timeout, q, [this]() {
+            slotDataTimer();
+        });
     }
     mConfigFile = QStandardPaths::writableLocation(QStandardPaths::ConfigLocation) + QStringLiteral("/kabldaprc");
     KDirWatch::self()->addFile(mConfigFile);
@@ -214,7 +221,11 @@ void LdapClientSearch::Private::slotFileChanged(const QString &file)
 void LdapClientSearch::startSearch(const QString &txt)
 {
     if (d->mNoLDAPLookup) {
+#if QT_VERSION >= QT_VERSION_CHECK(5, 10, 0)
+        QMetaObject::invokeMethod(this, &LdapClientSearch::searchDone, Qt::QueuedConnection);
+#else
         QMetaObject::invokeMethod(this, "searchDone", Qt::QueuedConnection);
+#endif
         return;
     }
 
