@@ -7,7 +7,7 @@
   Copyright (c) 2001 Waldo Bastian <bastian@kde.org>
   Copyright (c) 2004 Daniel Molkentin <danimo@klaralvdalens-datakonsult.se>
   Copyright (c) 2004 Karl-Heinz Zimmer <khz@klaralvdalens-datakonsult.se>
-  Copyright (c) 2017 Laurent Montel <montel@kde.org>
+  Copyright (C) 2017-2018 Laurent Montel <montel@kde.org>
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
@@ -70,7 +70,7 @@ public:
     /**
      * Destroys the addressee line edit.
      */
-    virtual ~AddresseeLineEdit();
+    ~AddresseeLineEdit() override;
 
     /**
      * Sets whether semicolons are allowed as separators.
